==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Spatial_searching/group__SplitterClasses.js <==
var group__SplitterClasses =
[
    [ "Fair", "classCGAL_1_1Fair.html", [
      [ "FT", "classCGAL_1_1Fair.html#ab3854252f562f68025b16231b4539a1d", null ],
      [ "Fair", "classCGAL_1_1Fair.html#a6adb4a55ddda826646db08f458d0d4fa", null ],
      [ "Fair", "classCGAL_1_1Fair.html#a83fa092234f53bda0c223bf058209a22", null ]
    ] ],
    [ "Median_of_max_spread", "classCGAL_1_1Median__of__max__spread.html", [
      [ "Median_of_max_spread", "classCGAL_1_1Median__of__max__spread.html#a938fa2463a54f6c01af6e97ab4b90607", null ],
      [ "Median_of_max_spread", "classCGAL_1_1Median__of__max__spread.html#a8a8fb631d2faeec304b64819261ad948", null ]
    ] ],
    [ "Median_of_rectangle", "classCGAL_1_1Median__of__rectangle.html", [
      [ "Median_of_rectangle", "classCGAL_1_1Median__of__rectangle.html#a797971cadc3137449b0e415dc8403cbc", null ],
      [ "Median_of_rectangle", "classCGAL_1_1Median__of__rectangle.html#a769e084428eb174eddf07ff375b767e6", null ]
    ] ],
    [ "Midpoint_of_max_spread", "classCGAL_1_1Midpoint__of__max__spread.html", [
      [ "Midpoint_of_max_spread", "classCGAL_1_1Midpoint__of__max__spread.html#a7000f0d1646706a6bb6b7986bf23aad5", null ],
      [ "Midpoint_of_max_spread", "classCGAL_1_1Midpoint__of__max__spread.html#a499e339e23ccc724af2afab14625198f", null ]
    ] ],
    [ "Midpoint_of_rectangle", "classCGAL_1_1Midpoint__of__rectangle.html", [
      [ "Midpoint_of_rectangle", "classCGAL_1_1Midpoint__of__rectangle.html#a3fc40c58fa0b606b355fe774b4885835", null ],
      [ "Midpoint_of_rectangle_spread", "classCGAL_1_1Midpoint__of__rectangle.html#a7a4372ccbdebcd951b255de330f3b169", null ]
    ] ],
    [ "Sliding_fair", "classCGAL_1_1Sliding__fair.html", [
      [ "FT", "classCGAL_1_1Sliding__fair.html#af4a68803503d6e011268fe513b470a2d", null ],
      [ "Sliding_fair", "classCGAL_1_1Sliding__fair.html#aac84d5b455224065ee5ceb030c56df81", null ],
      [ "aspect_ratio", "classCGAL_1_1Sliding__fair.html#a505cecadbac03cb2c4a382d7e24346a9", null ],
      [ "bucket_size", "classCGAL_1_1Sliding__fair.html#a6f2f76a084a872b58f17507a603e8f44", null ]
    ] ],
    [ "Sliding_midpoint", "classCGAL_1_1Sliding__midpoint.html", [
      [ "Sliding_midpoint", "classCGAL_1_1Sliding__midpoint.html#aa855083c2a2ff0af338e53d8d71b6c7e", null ],
      [ "bucket_size", "classCGAL_1_1Sliding__midpoint.html#aed0dee318d55e3ee0ff2a3c20d71c6cf", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Spatial_searching/group__SplitterClasses.js <==
var group__SplitterClasses =
[
    [ "CGAL::Fair< Traits, SpatialSeparator >", "classCGAL_1_1Fair.html", [
      [ "FT", "classCGAL_1_1Fair.html#ab3854252f562f68025b16231b4539a1d", null ],
      [ "Fair", "classCGAL_1_1Fair.html#a6adb4a55ddda826646db08f458d0d4fa", null ],
      [ "Fair", "classCGAL_1_1Fair.html#a83fa092234f53bda0c223bf058209a22", null ]
    ] ],
    [ "CGAL::Median_of_max_spread< Traits, SpatialSeparator >", "classCGAL_1_1Median__of__max__spread.html", [
      [ "Median_of_max_spread", "classCGAL_1_1Median__of__max__spread.html#a938fa2463a54f6c01af6e97ab4b90607", null ],
      [ "Median_of_max_spread", "classCGAL_1_1Median__of__max__spread.html#a8a8fb631d2faeec304b64819261ad948", null ]
    ] ],
    [ "CGAL::Median_of_rectangle< Traits, SpatialSeparator >", "classCGAL_1_1Median__of__rectangle.html", [
      [ "Median_of_rectangle", "classCGAL_1_1Median__of__rectangle.html#a797971cadc3137449b0e415dc8403cbc", null ],
      [ "Median_of_rectangle", "classCGAL_1_1Median__of__rectangle.html#a769e084428eb174eddf07ff375b767e6", null ]
    ] ],
    [ "CGAL::Midpoint_of_max_spread< Traits, SpatialSeparator >", "classCGAL_1_1Midpoint__of__max__spread.html", [
      [ "Midpoint_of_max_spread", "classCGAL_1_1Midpoint__of__max__spread.html#a7000f0d1646706a6bb6b7986bf23aad5", null ],
      [ "Midpoint_of_max_spread", "classCGAL_1_1Midpoint__of__max__spread.html#a499e339e23ccc724af2afab14625198f", null ]
    ] ],
    [ "CGAL::Midpoint_of_rectangle< Traits, SpatialSeparator >", "classCGAL_1_1Midpoint__of__rectangle.html", [
      [ "Midpoint_of_rectangle", "classCGAL_1_1Midpoint__of__rectangle.html#a3fc40c58fa0b606b355fe774b4885835", null ],
      [ "Midpoint_of_rectangle_spread", "classCGAL_1_1Midpoint__of__rectangle.html#a7a4372ccbdebcd951b255de330f3b169", null ]
    ] ],
    [ "CGAL::Sliding_fair< Traits, SpatialSeparator >", "classCGAL_1_1Sliding__fair.html", [
      [ "FT", "classCGAL_1_1Sliding__fair.html#af4a68803503d6e011268fe513b470a2d", null ],
      [ "Sliding_fair", "classCGAL_1_1Sliding__fair.html#aac84d5b455224065ee5ceb030c56df81", null ],
      [ "aspect_ratio", "classCGAL_1_1Sliding__fair.html#a505cecadbac03cb2c4a382d7e24346a9", null ],
      [ "bucket_size", "classCGAL_1_1Sliding__fair.html#a6f2f76a084a872b58f17507a603e8f44", null ]
    ] ],
    [ "CGAL::Sliding_midpoint< Traits, SpatialSeparator >", "classCGAL_1_1Sliding__midpoint.html", [
      [ "Sliding_midpoint", "classCGAL_1_1Sliding__midpoint.html#aa855083c2a2ff0af338e53d8d71b6c7e", null ],
      [ "bucket_size", "classCGAL_1_1Sliding__midpoint.html#aed0dee318d55e3ee0ff2a3c20d71c6cf", null ]
    ] ]
];
